/* This file was generated by syncqt. */
#ifndef QT_QTWEBSOCKETS_VERSION_H
#define QT_QTWEBSOCKETS_VERSION_H

#define QTWEBSOCKETS_VERSION_STR "5.15.16"

#define QTWEBSOCKETS_VERSION 0x050F10

#endif // QT_QTWEBSOCKETS_VERSION_H
